/**
 *
 *  Betterville Dozy Girl
 *  @author Drakkos
 *  @started 27/03/2009
 *
 */
 
#include "path.h"

// We've created a simple NPC inherit, and this is the one we use 
// instead of /obj/monster
inherit INHERITS + "betterville_npc";

void setup() {
  //  Create an array for NPC types - this ensures variation.
  string *types = ({"gold digger", "wannabe princess", 
    "upwardly mobile socialite"});  
  // Setup an array of places for the NPC to come from - we 
  // use this to setup nationalities and long descriptions.
  string *places = ({"Lancre Town", "Genua", "Sto Lat"});
  
  // Pick a random place for them to have been from.
  string place = element_of (places);
  // Pick a random type for the NPC.
  string type = element_of (types);
  string *arr;
  string name;
  
  // Setup each of the possible features the NPC has.
  string *lengths = ({"long", "short"});
  string *colours = ({"blonde", "brunette", "red", "black"});
  string *weights = ({"fat", "thin", "skeletal", "plump", "well-built"});
  string *heights = ({"tall", "short"});
  
  string str = "";
  
  // Turn the type we select into an array - so "gold digger" becomes 
  // ({"gold", "digger"})
  arr = explode (type, " ");
  // Get the last element from the array and store it as 'name'.
  name = arr[<1]; 
  // Subtract the last element from the array (the one we have stored 
  // as name)
  arr -= ({ arr[<1] });
  
  // Set the name
  set_name (name);
  
  // Add an adjective for each remaining part of the array.
  foreach (string a in arr) {
    add_adjective (a);
  }
  
  // Usual setup things
  set_short (type);
  basic_setup ("human", "warrior", 25 + random (25));
  set_gender (2);

  // Here is where we turn the random place we selected into a long
  // description and a nationality.
  switch (place) {
    case "Lancre Town":
      str += "This is a girl from Lancre Town.  Lancre has few opportunities "
        "for social mobility ever since Verence married Magrat, and so she "
        "has come here hoping to improve her lot in life.  ";
      setup_nationality ("/std/nationality/lancre", "Lancre Town");
    break;
    case "Genua":
      str += "This is a girl from Genua.  Genua City is full of opportunities "
        "for girls looking to marry into wealth, but this is done in a "
        "cutthroat environment of vicious competition.  She has come "
        "to Betterville in the hope of finding an easier time of it in the "
        "Provinces.  ";
      setup_nationality ("/std/nationality/genua", "Genua");
    break;
    case "Sto Lat":
      str += "This is a girl from Sto Lat.  In the city of Sto Lat, $weight$ "
        "girls like this are not especially sought after by the courtiers, "
        "and so she has come here to find love with someone easier to "
        "please.  Or at least, easier to please for someone of her gender.  ";
      setup_nationality ("/std/nationality/morpork", "Sto Lat");
    break;  
  } 
 
  // Add on some random features for additional dynamics.
  str += "She is a $height$, $weight$ girl wih $length$ $colour$ hair.\n";
  
  // The replace efun allows you to replace instances of one word with 
  // another.  It gets setup in an array in the form of alternating 
  // strings - the first is the text to replace, the second is the 
  // text to replace it with.  So for example, $height$ gets replaced 
  // with a random element taken from the heights array.
  str = replace (str, ({
    "$height$", element_of (heights),
    "$weight$", element_of (weights),
    "$length$", element_of (lengths),
    "$colour$", element_of (colours),
  }));         
         
  // Set the long description to be the string we have built.
  set_long (str);
  
  
  // Setup the load chats.
  load_chat(120,
  ({
    1, "' I could be the one his One True Love, I know it!",
    1, "' I have travelled far to get here, but love awaits me.",
    1, "' I wonder what I'll spend his vast fortune on first when "
      "I have broken the curse...",
    1, "' Have you seen the Beast?  I'm going to be his one true love.",
    1, "' They say a kiss will turn him back into a prince.",
    1, "' We're going to get married in the spring. You know, when I find him.",
    1, "' All these other girls are fools if they think they are his One."
  }));

  // Set up the attack chats.
  load_a_chat(120,
  ({
    1, "' Help, my Love will save me!",
    1, "' I don't remember this part of the fairy-tale!",
    1, "' The Beast won't be happy you're killing his one true love!",
    1, "' Stop, this is part of a different story!",
    1, "' I think we all know who the real beast here is!"
  }));

}

// This method is called whenever an NPC dies in the inventory or the 
// environment of this NPC.
void event_death(object ob, object *killers, object killer, string 
  room_mess, string killer_mess) {
   
  // Check to see if this NPC is part of the array of attackers in 
  // the dead NPC.
  if (member_array (this_object(), killers) != -1) {
    // We are, so express surprise!
    init_command ("' Oh, did I do that?", 1);
  }
  // Otherwise, if we're not the one who just died...
  else if (ob != this_object()) {
    // Express our distate that someone just died in front of us.
    init_command ("' Oh, how horrid!", 1);
  }
  
  // Make sure that any inherited event_death methods get executed
  // properly.
  ::event_death (ob, killers, killer, room_mess, killer_mess);
}

// This method is called repeatedly during combat.
void event_fight_in_progress(object me, object him) {
  // Make sure we're not one of the people involved in the
  // combat.
  if (me != this_object() && him != this_object()) {
    // Since this event occurs repeatedly during a combat, we 
    // need some way to limit how often this gets said.  We
    // base it on random number generation.
    if (!random (10)) {
      do_command ("' Stop fighting, you beastly brutes!");
    }
  }
  
  ::event_fight_in_progress (me, him);
}

// This method gets called as a natural part of the death processing.
// We can use it to provide some custom death functionality for this 
// NPC.
int second_life() {
  do_command ("' What a sad ending to a beautiful love story!");
  return 0;
}