/**
 *
 *  Betterville Disembowel Handler
 *  @author Drakkos
 *  @started 29/03/2009
 *
 */

#include "path.h"

string *to_punish;

void load_me();
void save_me();

void create() {
  seteuid (geteuid());

  to_punish = ({ });

  // Call the load_me method to reinstate the data of the handler.  
  load_me();
}

/**
 *
 *  This method turns an object or a string into a consistent 
 *  value.  It returns the name of the parameter being passed
 *  in.
 *
 *  @param      player      The variable to get the name of
 *  @returns                The name associated with the variable.
 *
 */
 
private string query_player_name (mixed player) {
  if (objectp (player)) {
    return player->query_name();
  }
  
  if (stringp (player)) {
    return player;
  }
  
  return "Er, what?";
}

/**
 *
 *  Adds a player to be punished.  It will only allow a player
 *  to be added once to the list.
 *
 *  @param      player        The player to add to the list
 *
 */
 
void add_to_punish (mixed player) {
  string str = query_player_name (player);
  
  if (member_array (str, to_punish) == -1) {
    to_punish += ({ str });
    save_me();
  }
}

/**
 *
 *  Determines whether a particular player is due to be punished.
 *
 *  @param      player        The player to query
 *  @returns                  1 if they are to be punished, 0 if they are not.
 *
 */
 
int query_to_be_punished (mixed player) {
  string str = query_player_name (player);

  if (member_array (str, to_punish) == -1) {
    return 0;
  }
  return 1;
}

/**
 *
 *  Removed a player from the punishment array.  It will only allow a player
 *  to be added once to the list.
 *
 *  @param      player        The player to add to the list
 *
 */

void remove_to_punish (mixed player) {
  string str = query_player_name (player);

  to_punish -= ({ str });
  save_me();
}

/**
 *
 *  Save the state of the handler.
 *
 */

void save_me() {
  // Do an unguarded apply of the save_object call.  This stops the 
  // permissions checking at this_object, and not at the interactive 
  // that caused the function to execute.  The '2' parameter in the 
  // save_object call means that the file will be saved in a compressed
  // format.
  unguarded ((: save_object (SAVE + "disembowel_save", 2) :));
}

/**
 *
 *  Restore the state of the handler.
 *
 */

void load_me() {
  // Do an unguarded apply of the restore_object call.  This stops the 
  // permissions checking at this_object, and not at the interactive 
  // that caused the function to execute. 
  unguarded ((: restore_object (SAVE + "disembowel_save") :));
}